# xtal

[![Build Status](https://travis-ci.org/USCCACS/xtal.svg?branch=master)](https://travis-ci.org/USCCACS/xtal) [![Coverage Status](https://coveralls.io/repos/github/USCCACS/xtal/badge.svg?branch=master)](https://coveralls.io/github/USCCACS/xtal?branch=master)

xtal is an umbrella package for various tools used to manipulate atomic trajectories. Works with LAMMPS, RXMD, and VASP structure files.


## Installation

Install from PyPI using
```
python3 -m pip install xtal
```


## Contributing

Contributing to xtal is easy, simply fork the repo, add your code and documentation and submit a pull request. For consistency with the existing codebase, please follow the [Google Python style guide](https://google.github.io/styleguide/pyguide.html) as closely as possible.


## License

The xtal source code and documentation are distributed 'as is' under the [MIT License](LICENSE).
